array_to_mesh — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# array_to_mesh

static ElectronicBandStructure.array_to_mesh(array, nkx, nky, nkz)

  Converts a list to a mesh that corresponds to ebs.kpoints [n_kx*n_ky*n_kz,…]->[n_kx,n_ky,n_kz,…]. Make sure array is sorted by lexisort

  Parameters:

    - array (np.ndarray) – The array to convert to a mesh

    - nkx (int) – The number of kx points

    - nky (int) – The number of ky points

    - nkz (int) – The number of kz points

  Returns:

    np.ndarray – mesh